has static method

bool has(
  1. String key
)

Checks if a value with the specified key exists in the cache.

  • Parameter key The unique identifier for the cached value.
  • Returns: true if the key is present in the cache, otherwise false. Usage:
var exists = Cache.has("user");

Implementation

static bool has(String key) => cacheDriver.has(key);