ObserverWrapper<T> class
- Implemented types
Constructors
-
ObserverWrapper(CacheObserver<
T> observer, String key)
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- identifier → String
-
final
- key → String
-
final
-
observer
→ CacheObserver<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDelete(
String key) → void -
override
-
onUpdate(
String key, T newValue) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override